/*
 * Copyright 2012-2017 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.launcher.internal;

import static junit.framework.Assert.assertEquals;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import java.util.LinkedList;
import java.util.List;

import com.redhat.thermostat.common.config.ClientPreferences;
import org.junit.Test;

public class DbUrlCompleterTest {

    @Test
    public void testDbUrlCompleter() {
        ClientPreferences prefs = mock(ClientPreferences.class);
        DbUrlCompleter dbUrlCompleter = new DbUrlCompleter(prefs);

        String partialUrl = "https://ip.addr";
        String fullUrl = partialUrl + "ess.example.com:25813/thermostat/storage";
        when(prefs.getConnectionUrl()).thenReturn(fullUrl);

        List<CharSequence> candidates = new LinkedList<>();
        dbUrlCompleter.complete(partialUrl, partialUrl.length(), candidates);

        assertEquals(1, candidates.size());
        assertEquals(fullUrl, candidates.get(0).toString().trim());
    }
}
